@@ -26,7 +26,7 @@ from tiddlyweb.store import (NoBagError, NoRecipeError, NoTiddlerError,
 from tiddlyweb.stores import StorageInterface
 from tiddlyweb.util import binary_tiddler
 
-__version__ = '0.9.12'
+__version__ = '0.9.13'
 
 #logging.basicConfig()
 #logging.getLogger('sqlalchemy.engine').setLevel(logging.INFO)
@@ -50,10 +50,10 @@ revision_table = Table('revision', metadata,
     Column('tiddler_title', Unicode(128), index=True, nullable=False),
     Column('number', Integer, primary_key=True, nullable=False,
         autoincrement=True),
-    Column('modifier', Unicode(128)),
-    Column('modified', String(14)),
-    Column('type', String(128)),
-    Column('tags', Unicode(1024)),
+    Column('modifier', Unicode(128), index=True),
+    Column('modified', String(14), index=True),
+    Column('type', String(128), index=True),
+    Column('tags', Unicode(1024), index=True),
     Column('text', UnicodeText(16777215), nullable=False, default=u''),
     UniqueConstraint('bag_name', 'tiddler_title', 'number'),
     ForeignKeyConstraint(['bag_name', 'tiddler_title'],
